# Dolosse
Dolosse uses modern tools such as Kafka and PostgreSQL to provide a scientific data acquisition 
framework. The project is python based, which allows us to take advantage of a vast array of analysis
libraries.

## Source Organization
We are actively designing the software.  The basic organization will change drastically as we start 
to determine the components and pieces.  

## Licensing
We license the software under the Apache License 2.0. See the LICENSE for more information. Each 
contributor is expected to put their name in their code.  

Copyright 2019 S. V. Paulauskas